@@ -435,7 +435,7 @@ class Client(object):
         self.scheduler = coerce_to_rpc(self._start_arg, timeout=timeout)
         self.scheduler_stream = None
 
-        yield self.ensure_connected()
+        yield self.ensure_connected(timeout=timeout)
 
         self.coroutines.append(self._handle_report())
 
@@ -458,12 +458,13 @@ class Client(object):
                     yield gen.sleep(timeout)
 
     @gen.coroutine
-    def ensure_connected(self):
+    def ensure_connected(self, timeout=3):
         if self.scheduler_stream and not self.scheduler_stream.closed():
             return
 
         try:
-            stream = yield connect(self.scheduler.ip, self.scheduler.port)
+            stream = yield connect(self.scheduler.ip, self.scheduler.port,
+                                   timeout=timeout)
         except:
             raise IOError("Could not connect to %s:%d" %
                           (self.scheduler.ip, self.scheduler.port))
@@ -528,8 +529,8 @@ class Client(object):
                 try:
                     msgs = yield read(self.scheduler_stream.stream)
                 except StreamClosedError:
-                    logger.warn("Client report stream closed to scheduler")
                     if self.status == 'running':
+                        logger.warn("Client report stream closed to scheduler")
                         logger.info("Reconnecting...")
                         self.status = 'connecting'
                         yield self.reconnect()
@@ -552,8 +553,11 @@ class Client(object):
                         breakout = True
                         break
 
-                    handler = self._handlers[op]
-                    handler(**msg)
+                    try:
+                        handler = self._handlers[op]
+                        handler(**msg)
+                    except Exception as e:
+                        logger.exception(e)
                 if breakout:
                     break
 
@@ -905,8 +909,9 @@ class Client(object):
 
             if response['status'] == 'error':
                 logger.warn("Couldn't gather keys %s", response['keys'])
-                self._send_to_scheduler({'op': 'missing-data',
-                                         'keys': response['keys']})
+                for key in response['keys']:
+                    self._send_to_scheduler({'op': 'report-key',
+                                             'key': key})
                 for key in response['keys']:
                     self.futures[key].event.clear()
             else:
@@ -1204,7 +1209,7 @@ class Client(object):
         --------
         Client.publish_dataset
         """
-        return sync(self.loop, self.scheduler.publist_delete, name=name)
+        return sync(self.loop, self.scheduler.publish_delete, name=name)
 
     def list_datasets(self):
         """
@@ -1373,7 +1378,6 @@ class Client(object):
                                  'keys': list(flatkeys),
                                  'restrictions': restrictions or {},
                                  'loose_restrictions': loose_restrictions,
-                                 'client': self.id,
                                  'priority': priority,
                                  'resources': resources})
 
@@ -2362,6 +2366,10 @@ def as_completed(fs):
     fs = list(fs)
     if not fs:
         return
+    non_futures = [f for f in fs if not isinstance(f, Future)]
+    if non_futures:
+        raise TypeError("Using as_completed on non-future objects: %s" %
+                        non_futures)
     if len(set(f.client for f in fs)) == 1:
         loop = first(fs).client.loop
     else:
