@@ -4,11 +4,14 @@ from functools import partial
 import logging
 
 try:
-    import pandas.msgpack as msgpack
-except ImportError:
     import msgpack
+except ImportError:
+    import pandas.msgpack as msgpack
 
-from toolz import get_in
+try:
+    from cytoolz import get_in
+except ImportError:
+    from toolz import get_in
 
 from .compression import compressions, maybe_compress
 from .serialize import (serialize, deserialize, Serialize, Serialized,
@@ -40,8 +43,8 @@ def dumps(msg):
                if type(value) is Serialized}
 
         data = {key: serialize(value.data)
-                     for key, value in data.items()
-                     if type(value) is Serialize}
+                for key, value in data.items()
+                if type(value) is Serialize}
 
         header = {'headers': {},
                   'keys': [],
@@ -117,7 +120,7 @@ def loads(frames, deserialize=True):
 
         return msg
     except Exception as e:
-        logger.critical("Failed to deerialize", exc_info=True)
+        logger.critical("Failed to deserialize", exc_info=True)
         raise
 
 
