@@ -10,6 +10,7 @@ try:
 except ImportError:
     blosc = False
 
+from .compression import byte_sample
 from .utils import frame_split_size
 from .serialize import register_serialization
 from . import pickle
@@ -49,13 +50,25 @@ def serialize_numpy_ndarray(x):
 
     data = x.view('u1').data
 
-    if blosc:
+    if blosc and len(data) > 1e5:
         frames = frame_split_size([data])
         if sys.version_info.major == 2:
             frames = [ensure_bytes(frame) for frame in frames]
-        frames = [blosc.compress(frame, typesize=size,
-                                 cname='lz4', clevel=5) for frame in frames]
-        header['compression'] = ['blosc'] * len(frames)
+
+        out = []
+        compression = []
+        for frame in frames:
+            sample = byte_sample(frame, 10000 * size, 5)
+            csample = blosc.compress(sample, typesize=size, cname='lz4', clevel=3)
+            if len(csample) < 0.8 * len(sample):
+                compressed = blosc.compress(frame, typesize=size, cname='lz4', clevel=5)
+                out.append(compressed)
+                compression.append('blosc')
+            else:
+                out.append(frame)
+                compression.append(None)
+        header['compression'] = compression
+        frames = out
     else:
         frames = [data]
 
